==> phoenix_1.1.0.tgz: phoenix/phoenix_rubric.md <==
| Organ System                                                          | 0 Points                         | 1 Point                 | 2 Points                 | 3 Points | 
| :------                                                               | :--                              | :--                     | :--                      | :--      | 
| **Respiratory** (0-3 points)                                          |                                  |                         |                          |          | 
|                                                                       |                                  | Any respiratory support | IMV^a^                   | IMV      | 
| &nbsp;&nbsp;PaO~2~:FiO~2~                                             | &geq; 400                        | < 400                   | < 200                    | < 100    | 
| &nbsp;&nbsp;SpO~2~:FiO~2~^b^                                          | &geq; 292                        | < 292                   | < 220                    | < 148    | 
| **Cardiovascular** (0-6 points; sum of medications, Lactate, and MAP) |                                  |                         |                          |          | 
| &nbsp;&nbsp; Systemic Vasoactive Medications^c^                       | No medications                   | 1 medication            | 2 or more medications    |          | 
| &nbsp;&nbsp; Lactate^d^ (mmol/L)                                      | &lt; 5                           | 5 &leg; Lactate &lt; 11 | &geq; 11                 |          | 
| &nbsp;&nbsp; Age^e^ (months) adjusted MAP^f^ (mmHg)                   |                                  |                         |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;   0 &leq; Age &lt;   1                       | &geq; 31                         | 17 &leq; MAP &lt; 31    | &lt; 17                  |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;   1 &leq; Age &lt;  12                       | &geq; 39                         | 25 &leq; MAP &lt; 39    | &lt; 25                  |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  12 &leq; Age &lt;  24                       | &geq; 44                         | 31 &leq; MAP &lt; 44    | &lt; 31                  |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  24 &leq; Age &lt;  60                       | &geq; 45                         | 32 &leq; MAP &lt; 45    | &lt; 32                  |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  60 &leq; Age &lt; 144                       | &geq; 49                         | 36 &leq; MAP &lt; 49    | &lt; 36                  |          | 
| &nbsp;&nbsp;&nbsp;&nbsp; 144 &leq; Age &lt; 216                       | &geq; 52                         | 38 &leq; MAP &lt; 52    | &lt; 38                  |          | 
| **Coagulation**^g^ (0-2 points; 1 for each lab; max of 2 points)      |                                  |                         |                          |          | 
| &nbsp;&nbsp; Platelets (1000/&mu;L)                                   | &geq; 100                        | &lt; 100                |                          |          | 
| &nbsp;&nbsp; INR                                                      | &leq; 1.3                        | &gt; 1.3                |                          |          | 
| &nbsp;&nbsp; D-Dimer (mg/L FEU)                                       | &leq; 2                          | &gt; 2                  |                          |          | 
| &nbsp;&nbsp; Fibrinogen (mg/dL)                                       | &geq; 100                        | &lt; 100                |                          |          | 
| **Neurologic**^h^ (0-2 points)                                        |                                  |                         |                          |          | 
| &nbsp;&nbsp;                                                          | GCS^i^ &geq; 11                  | GCS &leq; 10            | Bilaterally fixed pupils |          | 
| **Endocrine** (0-1 point)                                             |                                  |                         |                          |          | 
| &nbsp;&nbsp; Blood Glucose (mg/dL)                                    | 50 &leq; Blood Glucose &leq; 150 | &lt; 50; or &gt; 150    |                          |          | 
| **Immunologic** (0-1 point; point from ANC and/or ALC)                |                                  |                         |                          |          | 
| &nbsp;&nbsp; ANC (cells/mm^3^)                                        | &geq; 500                        | &lt; 500                |                          |          | 
| &nbsp;&nbsp; ALC (cells/mm^3^)                                        | &geq; 1000                       | &lt; 1000               |                          |          | 
| **Renal** (0-1 point)                                                 |                                  |                         |                          |          | 
| &nbsp;&nbsp; Age^e^ (months) adjusted Creatinine (mg/dL)              |                                  |                         |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;   0 &leq; Age &lt;   1                       | &lt; 0.8                         | &geq; 0.8               |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;   1 &leq; Age &lt;  12                       | &lt; 0.3                         | &geq; 0.3               |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  12 &leq; Age &lt;  24                       | &lt; 0.4                         | &geq; 0.4               |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  24 &leq; Age &lt;  60                       | &lt; 0.6                         | &geq; 0.6               |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  60 &leq; Age &lt; 144                       | &lt; 0.7                         | &geq; 0.7               |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp; 144 &leq; Age &lt; 216                       | &lt; 1.0                         | &geq; 1.0               |                          |          | 
| **Hepatic** (0-1 point; point from total bilirubin and/or ALT)        |                                  |                         |                          |          | 
| &nbsp;&nbsp; Total Bilirubin (mg/dL)                                  | &lt; 4                           | &geq; 4                 |                          |          | 
| &nbsp;&nbsp; ALT (IU/L)                                               | &leq; 102                        | &gt; 102                |                          |          |

==> phoenix_1.1.1.tgz: phoenix/phoenix_rubric.md <==
| Organ System                                                          | 0 Points                         | 1 Point                 | 2 Points                 | 3 Points | 
| :------                                                               | :--                              | :--                     | :--                      | :--      | 
| **Respiratory** (0-3 points)                                          |                                  |                         |                          |          | 
|                                                                       |                                  | Any respiratory support | IMV^a^                   | IMV      | 
| &nbsp;&nbsp;PaO~2~:FiO~2~                                             | &geq; 400                        | < 400                   | < 200                    | < 100    | 
| &nbsp;&nbsp;SpO~2~:FiO~2~^b^                                          | &geq; 292                        | < 292                   | < 220                    | < 148    | 
| **Cardiovascular** (0-6 points; sum of medications, Lactate, and MAP) |                                  |                         |                          |          | 
| &nbsp;&nbsp; Systemic Vasoactive Medications^c^                       | No medications                   | 1 medication            | 2 or more medications    |          | 
| &nbsp;&nbsp; Lactate^d^ (mmol/L)                                      | &lt; 5                           | 5 &leq; Lactate &lt; 11 | &geq; 11                 |          | 
| &nbsp;&nbsp; Age^e^ (months) adjusted MAP^f^ (mmHg)                   |                                  |                         |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;   0 &leq; Age &lt;   1                       | &geq; 31                         | 17 &leq; MAP &lt; 31    | &lt; 17                  |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;   1 &leq; Age &lt;  12                       | &geq; 39                         | 25 &leq; MAP &lt; 39    | &lt; 25                  |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  12 &leq; Age &lt;  24                       | &geq; 44                         | 31 &leq; MAP &lt; 44    | &lt; 31                  |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  24 &leq; Age &lt;  60                       | &geq; 45                         | 32 &leq; MAP &lt; 45    | &lt; 32                  |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  60 &leq; Age &lt; 144                       | &geq; 49                         | 36 &leq; MAP &lt; 49    | &lt; 36                  |          | 
| &nbsp;&nbsp;&nbsp;&nbsp; 144 &leq; Age &lt; 216                       | &geq; 52                         | 38 &leq; MAP &lt; 52    | &lt; 38                  |          | 
| **Coagulation**^g^ (0-2 points; 1 for each lab; max of 2 points)      |                                  |                         |                          |          | 
| &nbsp;&nbsp; Platelets (1000/&mu;L)                                   | &geq; 100                        | &lt; 100                |                          |          | 
| &nbsp;&nbsp; INR                                                      | &leq; 1.3                        | &gt; 1.3                |                          |          | 
| &nbsp;&nbsp; D-Dimer (mg/L FEU)                                       | &leq; 2                          | &gt; 2                  |                          |          | 
| &nbsp;&nbsp; Fibrinogen (mg/dL)                                       | &geq; 100                        | &lt; 100                |                          |          | 
| **Neurologic**^h^ (0-2 points)                                        |                                  |                         |                          |          | 
| &nbsp;&nbsp;                                                          | GCS^i^ &geq; 11                  | GCS &leq; 10            | Bilaterally fixed pupils |          | 
| **Endocrine** (0-1 point)                                             |                                  |                         |                          |          | 
| &nbsp;&nbsp; Blood Glucose (mg/dL)                                    | 50 &leq; Blood Glucose &leq; 150 | &lt; 50; or &gt; 150    |                          |          | 
| **Immunologic** (0-1 point; point from ANC and/or ALC)                |                                  |                         |                          |          | 
| &nbsp;&nbsp; ANC (cells/mm^3^)                                        | &geq; 500                        | &lt; 500                |                          |          | 
| &nbsp;&nbsp; ALC (cells/mm^3^)                                        | &geq; 1000                       | &lt; 1000               |                          |          | 
| **Renal** (0-1 point)                                                 |                                  |                         |                          |          | 
| &nbsp;&nbsp; Age^e^ (months) adjusted Creatinine (mg/dL)              |                                  |                         |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;   0 &leq; Age &lt;   1                       | &lt; 0.8                         | &geq; 0.8               |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;   1 &leq; Age &lt;  12                       | &lt; 0.3                         | &geq; 0.3               |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  12 &leq; Age &lt;  24                       | &lt; 0.4                         | &geq; 0.4               |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  24 &leq; Age &lt;  60                       | &lt; 0.6                         | &geq; 0.6               |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp;  60 &leq; Age &lt; 144                       | &lt; 0.7                         | &geq; 0.7               |                          |          | 
| &nbsp;&nbsp;&nbsp;&nbsp; 144 &leq; Age &lt; 216                       | &lt; 1.0                         | &geq; 1.0               |                          |          | 
| **Hepatic** (0-1 point; point from total bilirubin and/or ALT)        |                                  |                         |                          |          | 
| &nbsp;&nbsp; Total Bilirubin (mg/dL)                                  | &lt; 4                           | &geq; 4                 |                          |          | 
| &nbsp;&nbsp; ALT (IU/L)                                               | &leq; 102                        | &gt; 102                |                          |          |
